@@ -29,7 +29,6 @@ from cognite_toolkit._cdf_tk.apps import (
     LandingApp,
     MigrateApp,
     ModulesApp,
-    PopulateApp,
     ProfileApp,
     PurgeApp,
     RepoApp,
@@ -100,9 +99,6 @@ if Plugins.dump.value.is_enabled():
 if Plugins.purge.value.is_enabled() and not Flags.v07.is_enabled():
     _app.add_typer(PurgeApp(**default_typer_kws), name="purge")
 
-if Flags.POPULATE.is_enabled():
-    _app.add_typer(PopulateApp(**default_typer_kws), name="populate")
-
 if Flags.PROFILE.is_enabled():
     _app.add_typer(ProfileApp(**default_typer_kws), name="profile")
 
