@@ -1,14 +1,15 @@
-from collections.abc import Hashable
+from collections.abc import Sequence
 from functools import partial
 from pathlib import Path
 
-from cognite.client.data_classes._base import CogniteResourceList, T_CogniteResourceList
+from cognite.client.data_classes._base import T_CogniteResource
 from pydantic import ValidationError
 from rich.console import Console
 
 from cognite_toolkit._cdf_tk.client import ToolkitClient
 from cognite_toolkit._cdf_tk.constants import DATA_MANIFEST_STEM, DATA_RESOURCE_DIR
-from cognite_toolkit._cdf_tk.storageio import StorageIO, T_Selector, are_same_kind, get_storage_io
+from cognite_toolkit._cdf_tk.storageio import T_Selector, UploadableStorageIO, are_same_kind, get_upload_io
+from cognite_toolkit._cdf_tk.storageio._base import T_WriteCogniteResource, UploadItem
 from cognite_toolkit._cdf_tk.storageio.selectors import Selector, SelectorAdapter
 from cognite_toolkit._cdf_tk.tk_warnings import HighSeverityWarning, MediumSeverityWarning
 from cognite_toolkit._cdf_tk.tk_warnings.fileread import ResourceFormatWarning
@@ -16,10 +17,10 @@ from cognite_toolkit._cdf_tk.utils.auth import EnvironmentVariables
 from cognite_toolkit._cdf_tk.utils.collection import chunker
 from cognite_toolkit._cdf_tk.utils.file import read_yaml_file
 from cognite_toolkit._cdf_tk.utils.fileio import FileReader
-from cognite_toolkit._cdf_tk.utils.http_client import HTTPClient, ItemIDMessage, SuccessItem
+from cognite_toolkit._cdf_tk.utils.http_client import HTTPClient, ItemMessage, SuccessResponseItems
 from cognite_toolkit._cdf_tk.utils.producer_worker import ProducerWorkerExecutor
 from cognite_toolkit._cdf_tk.utils.progress_tracker import ProgressTracker
-from cognite_toolkit._cdf_tk.utils.useful_types import T_ID, JsonVal, T_WritableCogniteResourceList
+from cognite_toolkit._cdf_tk.utils.useful_types import JsonVal
 from cognite_toolkit._cdf_tk.validation import humanize_validation_error
 
 from ._base import ToolkitCommand
@@ -175,11 +176,14 @@ class UploadCommand(ToolkitCommand):
                 for data_file in datafiles:
                     file_display = self._path_as_display_name(data_file)
                     if verbose:
-                        console.print(f"{action} {io.DISPLAY_NAME} from {file_display.as_posix()!r}")
+                        console.print(f"{action} {selector.display_name} from {file_display.as_posix()!r}")
                     reader = FileReader.from_filepath(data_file)
-                    tracker = ProgressTracker[Hashable]([self._UPLOAD])
-                    executor = ProducerWorkerExecutor[list[dict[str, JsonVal]], CogniteResourceList](
-                        download_iterable=chunker(reader.read_chunks(), io.CHUNK_SIZE),
+                    tracker = ProgressTracker[str]([self._UPLOAD])
+                    executor = ProducerWorkerExecutor[list[tuple[str, dict[str, JsonVal]]], Sequence[UploadItem]](
+                        download_iterable=chunker(
+                            ((f"line {line_no}", item) for line_no, item in enumerate(reader.read_chunks(), 1)),
+                            io.CHUNK_SIZE,
+                        ),
                         process=io.json_chunk_to_data,
                         write=partial(
                             self._upload_items,
@@ -194,7 +198,7 @@ class UploadCommand(ToolkitCommand):
                         max_queue_size=self._MAX_QUEUE_SIZE,
                         download_description=f"Reading {file_count:,}/{total_file_count + 1:,}: {file_display.as_posix()!s}",
                         process_description="Processing",
-                        write_description=f"{action} {io.DISPLAY_NAME!r}",
+                        write_description=f"{action} {selector.display_name!r}",
                         console=console,
                     )
                     executor.run()
@@ -208,7 +212,7 @@ class UploadCommand(ToolkitCommand):
                     if failed > 0:
                         suffix += f", {failed:,} failed"
                     console.print(
-                        f"{final_action} {success:,} {io.DISPLAY_NAME} from {file_display.as_posix()!r}{suffix}."
+                        f"{final_action} {success:,} {selector.display_name} from {file_display.as_posix()!r}{suffix}."
                     )
 
     @staticmethod
@@ -218,9 +222,11 @@ class UploadCommand(ToolkitCommand):
             display_name = input_path.relative_to(cwd)
         return display_name
 
-    def _create_selected_io(self, selector: Selector, data_file: Path, client: ToolkitClient) -> StorageIO | None:
+    def _create_selected_io(
+        self, selector: Selector, data_file: Path, client: ToolkitClient
+    ) -> UploadableStorageIO | None:
         try:
-            io_cls = get_storage_io(type(selector), kind=data_file)
+            io_cls = get_upload_io(type(selector), kind=data_file)
         except ValueError as e:
             self.warn(HighSeverityWarning(f"Could not find StorageIO for selector {selector}: {e}"))
             return None
@@ -229,23 +235,25 @@ class UploadCommand(ToolkitCommand):
     @classmethod
     def _upload_items(
         cls,
-        data_chunk: T_CogniteResourceList,
+        data_chunk: Sequence[UploadItem],
         upload_client: HTTPClient,
-        io: StorageIO[T_ID, T_Selector, T_CogniteResourceList, T_WritableCogniteResourceList],
+        io: UploadableStorageIO[T_Selector, T_CogniteResource, T_WriteCogniteResource],
         selector: T_Selector,
         dry_run: bool,
-        tracker: ProgressTracker[T_ID],
+        tracker: ProgressTracker[str],
         console: Console,
     ) -> None:
         if dry_run:
             for item in data_chunk:
-                tracker.set_progress(io.as_id(item), cls._UPLOAD, "success")
+                tracker.set_progress(item.source_id, cls._UPLOAD, "success")
             return
         results = io.upload_items(data_chunk, upload_client, selector)
-        for item in results:
-            if isinstance(item, SuccessItem):
-                tracker.set_progress(item.id, step=cls._UPLOAD, status="success")
-            elif isinstance(item, ItemIDMessage):
-                tracker.set_progress(item.id, step=cls._UPLOAD, status="failed")
+        for message in results:
+            if isinstance(message, SuccessResponseItems):
+                for id_ in message.ids:
+                    tracker.set_progress(id_, step=cls._UPLOAD, status="success")
+            elif isinstance(message, ItemMessage):
+                for id_ in message.ids:
+                    tracker.set_progress(id_, step=cls._UPLOAD, status="failed")
             else:
-                console.log(f"[red]Unexpected result from upload: {str(item)!r}[/red]")
+                console.log(f"[red]Unexpected result from upload: {str(message)!r}[/red]")
