@@ -1,10 +1,10 @@
 from cognite.client.data_classes._base import T_CogniteResourceList, T_WritableCogniteResource, T_WriteClass
 from cognite.client.utils.useful_types import SequenceNotStr
 
-from cognite_toolkit._cdf_tk.loaders import (
-    ResourceLoader,
+from cognite_toolkit._cdf_tk.cruds import (
+    ResourceCRUD,
 )
-from cognite_toolkit._cdf_tk.loaders._base_loaders import T_ID, T_WritableCogniteResourceList
+from cognite_toolkit._cdf_tk.cruds._base_cruds import T_ID, T_WritableCogniteResourceList
 
 
 def _print_ids_or_length(resource_ids: SequenceNotStr[T_ID], limit: int = 10) -> str:
@@ -18,7 +18,7 @@ def _print_ids_or_length(resource_ids: SequenceNotStr[T_ID], limit: int = 10) ->
 
 def _remove_duplicates(
     loaded_resources: T_CogniteResourceList,
-    loader: ResourceLoader[
+    loader: ResourceCRUD[
         T_ID, T_WriteClass, T_WritableCogniteResource, T_CogniteResourceList, T_WritableCogniteResourceList
     ],
 ) -> tuple[T_CogniteResourceList, list[T_ID]]:
