@@ -28,6 +28,14 @@ class TestDownloadCommand:
         chunks = list(NDJsonReader(downloaded_files[0]).read_chunks())
         assert len(chunks) == TIMESERIES_COUNT, f"Expected {TIMESERIES_COUNT} chunks, got {len(chunks)}."
         config_files = [file for file in tmp_path.rglob("*.yaml") if not file.stem.endswith(DATA_MANIFEST_STEM)]
-        assert len(config_files) == 1, "Expected exactly one configuration file to be created."
-        dumped = read_yaml_file(config_files[0], "dict")
+        assert len(config_files) == 2, (
+            f"Expected 2 configuration files (table and database), but found {len(config_files)}."
+        )
+        table_file = next((file for file in config_files if file.stem.endswith("Table")), None)
+        assert table_file is not None, "Table configuration file not found."
+        dumped = read_yaml_file(table_file, "dict")
         assert dumped == table.dump()["table"]
+        database_file = next((file for file in config_files if file.stem.endswith("Database")), None)
+        assert database_file is not None, f"Database configuration file not found. Found config files: {config_files}"
+        dumped_db = read_yaml_file(database_file, "dict")
+        assert dumped_db == {"dbName": table.table.db_name}
